@@ -53,33 +53,17 @@ class TestTocText:
                         ["Errors should never pass silently."],
                         ["Unless explicitly silenced."],
                         ["In the face of ambiguity, refuse the temptation to guess."],
-                        [
-                            par(
-                                """There should be one-- and preferably only one
-                                --obvious way to do it."""
-                            )
-                        ],
-                        [
-                            par(
-                                """Although that way may not be obvious at first
-                                unless you're Dutch."""
-                            )
-                        ],
+                        [par("""There should be one-- and preferably only one
+                                --obvious way to do it.""")],
+                        [par("""Although that way may not be obvious at first
+                                unless you're Dutch.""")],
                         ["Now is better than never."],
                         ["Although never is often better than *right* now."],
                         ["If the implementation is hard to explain, it's a bad idea."],
-                        [
-                            par(
-                                """If the implementation is easy to explain, it may
-                                be a good idea."""
-                            )
-                        ],
-                        [
-                            par(
-                                """Namespaces are one honking great idea -- let's do
-                                more of those!"""
-                            )
-                        ],
+                        [par("""If the implementation is easy to explain, it may
+                                be a good idea.""")],
+                        [par("""Namespaces are one honking great idea -- let's do
+                                more of those!""")],
                     ]
                 ],
             ]
